contact

# XMLRésuméLibrary: User Guide

company | Element Reference | copyright

## Name

contact — Container for one or more methods of contacting someone

## Synopsis

### Content Model

    (phone|fax|pager|email|url|instantMessage)*

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `contact` element is a container that holds elements that specify how to contact a person. The information it contains is similar to what would be printed on a business card.

### Parents

`contact` may be contained in these elements: `header`, `referee`

## See Also

`address`.

## Examples

    <contact>
      <phone>555-555-1212</phone>
      <email>sam.jones@xyz.bob</email>
      <url>http://www.xyz.bob/~sam.jones/</url>
    </contact>

    <contact>
      <phone>123-123-1234 x123</phone>
    </contact>

    <contact>
      <email>kawanza_eloma@hotmail.bob</email>
    </contact>

company | Element Reference | copyright